Comment

Comment by marceloaltmann

Straddled joins were still a bottleneck in Readyset even after switching to hash joins. By integrating Index Condition Pushdown into the execution path, we eliminated the inefficiency and achieved up to 450× speedups.

Discussion

Live from the official Hacker News API

A modern reader for Hacker News · SvelteKit + Skeleton